/***************************************************************************
                    draganddrop.cpp  -  Drag & Drop handler
                             -------------------
    begin                : Thu Aug 28 2003
    copyright            : (C) 2003 by Gabor Torok
    email                : cctorok@yahoo.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "../common/constants.h"
#include "draganddrop.h"

/**
  *@author Gabor Torok
  */

DragAndDropHandler::DragAndDropHandler() {
}
DragAndDropHandler::~DragAndDropHandler() {
}
